ParseErrorKind

Enum ParseErrorKind 

pub enum ParseErrorKind {
    OutOfRange,
    Impossible,
    NotEnough,
    Invalid,
    TooShort,
    TooLong,
    BadFormat,
    // some variants omitted
}
The category of parse error

Variants



OutOfRange

Given field is out of permitted range.



Impossible

There is no possible date and time value with given set of fields.

This does not include the out-of-range conditions, which are trivially invalid. It includes the case that there are one or more fields that are inconsistent to each other.



NotEnough

Given set of fields is not enough to make a requested date and time value.

Note that there may be a case that given fields constrain the possible values so much that there is a unique possible value. Chrono only tries to be correct for most useful sets of fields however, as such constraint solving can be expensive.



Invalid

The input string has some invalid character sequence for given formatting items.



TooShort

The input string has been prematurely ended.



TooLong

All formatting items have been read but there is a remaining input.



BadFormat

There was an error on the formatting string, or there were non-supported formatting items.